@@ -4,7 +4,7 @@ module.exports = function supportDefaultAssignment() {
 		var E = eval("class E { toString() { return 'default' } }");
 		var f1 = eval("(function f1({a, b = E}) {return new b().toString();})");
 		return f1({ a: "test" }) === "default";
-	} catch (e) {
+	} catch (_err) {
 		return false;
 	}
 };
